"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqlModule = exports.sqlGetAllRows = exports.sqlGetAllColumns = exports.sqlExecute = void 0;
const oracledb_1 = __importDefault(require("oracledb"));
const process_1 = require("process");
const dotenv_1 = __importDefault(require("dotenv"));
dotenv_1.default.config();
/**
 * @description This method is use to execute sql query
 * @param query SQL query string to execute
 */
const sqlExecute = async (query) => {
    const local = `${process_1.env.RUN || "LOCAL"}`;
    console.log("Setting environment variables...");
    const oracleClient = local === "LOCAL" ? "../instantclient_21_8" : `${process_1.env.WORKSPACE}/opt/oracle/instantclient_21_8`;
    if (!process_1.env.ORACLE_HOME) {
        console.log("Initializing Oracle Instant Client...");
        oracledb_1.default.initOracleClient({ libDir: oracleClient });
    }
    const db_user = process_1.env.DB_USER;
    const db_password = process_1.env.DB_PASSWORD;
    console.log("ATP DB Username:", db_user);
    console.log("ATP DB Password:", db_password);
    // Set connection string
    let connection, connectString;
    switch (String(process_1.env.ENVIRONMENT).toUpperCase()) {
        case "Ashburn(dev)":
            connectString = `dev_low`;
            break;
        case "Ashburn(iad_qapintlab1)":
            connectString = `qapintlab1_low`;
            break;
        case "Ashburn(iad_qa_chaos)":
            connectString = `qachaos_low`;
            break;
        default:
            connectString = `qapintlab1_low`;
    }
    console.log(`Connection string is set using: ${connectString}`);
    try {
        let binds, options;
        // Get Connection
        connection = await oracledb_1.default.getConnection({
            user: db_user,
            password: db_password,
            connectString: connectString,
        });
        console.log("Successfully connected to Oracle ATP Database");
        console.log(`Executing SQL Query: ${query}`);
        // Set Binds
        binds = {};
        // Set options
        options = {
            outFormat: oracledb_1.default.OUT_FORMAT_OBJECT,
            resultSet: false,
        };
        // Execute Query
        const result = await connection.execute(query, binds, options);
        console.log(`QUERY [${query}] RESULT: \n`, result);
        return result;
    }
    catch (err) {
        console.log(`${err.message}`);
        return err.message;
    }
    finally {
        if (connection) {
            try {
                await connection.close();
            }
            catch (err) {
                console.log(`${err.message}`);
            }
        }
    }
};
exports.sqlExecute = sqlExecute;
/**
 * @description This method gets all columns from a specified Database SQL Query
 *
 * @param response SQL query string to execute
 */
const sqlGetAllColumns = async (response) => {
    try {
        return response.metaData;
    }
    catch (error) {
        console.log("FAILED", error);
    }
};
exports.sqlGetAllColumns = sqlGetAllColumns;
/**
 * @description This method gets all rows from a specified Database SQL Query
 *
 * @param response SQL query string to execute
 */
const sqlGetAllRows = async (response) => {
    try {
        return response.rows;
    }
    catch (error) {
        console.log("FAILED", error);
    }
};
exports.sqlGetAllRows = sqlGetAllRows;
class SqlModule {
    /**
     * @description This method is use to execute sql query
     * @param query SQL query string to execute
     * @param column specific column from the result - Optional
     * @param orderByColumn specific column from the result - Optional
     * @param sort sort order (ASC or DESC) - Optional
     * @param rowCount specific row number from the result - Optional
     */
    async execute(dbParameters) {
        const local = `${process_1.env.RUN || "LOCAL"}`;
        console.log("Setting environment variables...");
        const oracleClient = local === "LOCAL" ? "../instantclient_21_8" : `${process_1.env.WORKSPACE}/opt/oracle/instantclient_21_8`;
        if (!process_1.env.ORACLE_HOME) {
            console.log("Initializing Oracle Instant Client...");
            oracledb_1.default.initOracleClient({ libDir: oracleClient });
        }
        const db_user = process_1.env.DB_USER;
        const db_password = process_1.env.DB_PASSWORD;
        console.log("ATP DB Username:", db_user);
        console.log("ATP DB Password:", db_password);
        let query = dbParameters.query;
        const column = dbParameters.column ? dbParameters.column : "";
        const orderByColumn = dbParameters.orderByColumn ? dbParameters.orderByColumn : "";
        const sort = dbParameters.sort ? dbParameters.sort : "";
        const rowCount = dbParameters.rowCount ? dbParameters.rowCount : "";
        // Form the SQL Query based on parameters
        query = column !== "" ? (query = query.replace("*", column)) : query; // to filter specific column
        query = orderByColumn !== "" ? (query = `${query} ORDER BY ${orderByColumn}`) : query; // to sort with specified column
        query = sort !== "" ? (query = `${query} ${sort}`) : query; // // to sort ascending or descending
        query = rowCount !== "" ? (query = `${query} FETCH FIRST ${rowCount} ROWS ONLY`) : query; // // to return specific number of rows
        // Set connection string
        let connection, connectString;
        switch (String(process_1.env.NODE_ENV).toUpperCase()) {
            case "DEV":
                connectString = `dev_low`;
                break;
            case "QA":
                connectString = `qa_low`;
                break;
            case "QAPINTLAB":
                connectString = `qapintlab1_low`;
                break;
            case "QACHAOS":
                connectString = `qachaos_low`;
                break;
            default:
                connectString = `qa_low`;
        }
        console.log(`Connection string is set using: ${connectString}`);
        try {
            let binds, options;
            // Get Connection
            connection = await oracledb_1.default.getConnection({
                user: db_user,
                password: db_password,
                connectString: connectString,
            });
            console.log("Successfully connected to Oracle ATP Database");
            console.log(`Executing SQL Query: ${query}`);
            // Set Binds
            binds = {};
            // Set options
            options = {
                outFormat: oracledb_1.default.OUT_FORMAT_OBJECT,
                resultSet: false,
            };
            // Execute Query
            const result = await connection.execute(query, binds, options);
            console.log(`QUERY [${query}] RESULT: \n`, result);
            return result;
        }
        catch (err) {
            console.log(`${err.message}`);
            return err.message;
        }
        finally {
            if (connection) {
                try {
                    await connection.close();
                }
                catch (err) {
                    console.log(`${err.message}`);
                }
            }
        }
    }
    /**
     * @description This method returns query result from specified column
     *
     * @param query SQL query string to execute
     * @param column specific column from the result
     */
    async getSingleColumn(dbParameters) {
        try {
            const result = await this.execute({
                query: dbParameters.query,
                column: dbParameters.column,
            });
            return result;
        }
        catch (error) {
            console.log("FAILED", error);
        }
    }
    /**
     * @description This method returns query result from specified column to be used for ascending order
     *
     * @param query SQL query string to execute
     * @param orderByColumn specific column from the result
     */
    async sortAscending(dbParameters) {
        try {
            const result = await this.execute({
                query: dbParameters.query,
                orderByColumn: dbParameters.orderByColumn,
                sort: "ASC",
            });
            return result;
        }
        catch (error) {
            console.log("FAILED", error);
        }
    }
    /**
     * @description This method returns query result from specified column to be used for ascending order
     *
     * @param query SQL query string to execute
     * @param orderByColumn specific column to sort
     */
    async sortDescending(dbParameters) {
        try {
            const result = await this.execute({
                query: dbParameters.query,
                orderByColumn: dbParameters.orderByColumn,
                sort: "DESC",
            });
            return result;
        }
        catch (error) {
            console.log("FAILED", error);
        }
    }
    /**
     * @description This method gets a specified number row from a result of Database SQL Query
     *
     * @param query SQL query string to execute
     * @param rowCount specific row number from the result
     */
    async getSpecificRow(dbParameters) {
        try {
            const result = await this.execute({
                query: dbParameters.query,
                rowCount: dbParameters.rowCount,
            });
            return result;
        }
        catch (error) {
            console.log("FAILED", error);
        }
    }
}
exports.SqlModule = SqlModule;
exports.default = new SqlModule();
//# sourceMappingURL=atp-db-connect.js.map